﻿using System;
using System.Diagnostics;
using System.IO;
using System.Windows.Forms;
using Winsoft.WebView;

namespace Browser
{
    public partial class FormMain : Form
    {
        public FormMain()
        {
            InitializeComponent();
        }

        private void FormMain_Load(object sender, EventArgs e)
        {
            toolStripTextBox.Text = webView.Uri;
            toolStrip_Resize(this, EventArgs.Empty);

            try
            {
                webView.Active = true;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message);
            }
        }

        private void UpdateControls()
        {
            toolStripButtonBack.Enabled = webView.CanBack;
            toolStripButtonForward.Enabled = webView.CanForward;
            toolStripButtonRefresh.Enabled = webView.Active;
            toolStripButtonZoomOut.Enabled = webView.Active;
            toolStripButtonZoomIn.Enabled = webView.Active;
            toolStripButtonCapture.Enabled = webView.Active;
        }

        private void toolStripButtonBack_Click(object sender, EventArgs e)
        {
            webView.Back();
        }

        private void toolStripButtonForward_Click(object sender, EventArgs e)
        {
            webView.Forward();
        }

        private void toolStripButtonRefresh_Click(object sender, EventArgs e)
        {
            webView.Reload();
        }

        private void toolStripButtonZoomOut_Click(object sender, EventArgs e)
        {
            webView.Zoom -= 0.1;
        }

        private void toolStripButtonZoomIn_Click(object sender, EventArgs e)
        {
            webView.Zoom += 0.1;
        }

        private void webView_DocumentTitleChanged(object sender, EventArgs e)
        {
            Text = "WebView - " + webView.DocumentTitle;
        }

        private void webView_Activated(object sender, EventArgs e)
        {
            UpdateControls();
        }

        private void FormMain_FormClosed(object sender, FormClosedEventArgs e)
        {
            webView.Active = false;
        }

        private void webView_NavigationStarting(object sender, Winsoft.WebView.NavigationStartingEventArgs e)
        {
            UpdateControls();
            toolStripButtonStop.Enabled = true;
        }

        private void webView_NavigationCompleted(object sender, Winsoft.WebView.NavigationCompletedEventArgs e)
        {
            UpdateControls();
            toolStripButtonStop.Enabled = false;
            toolStripTextBox.Text = webView.Uri;
        }

        private void toolStripButtonStop_Click(object sender, EventArgs e)
        {
            webView.Stop();
            toolStripButtonStop.Enabled = false;
            toolStripTextBox.Text = webView.Uri;
            UpdateControls();
        }

        private void toolStrip_Resize(object sender, EventArgs e)
        {
            toolStripTextBox.Width = toolStrip.Right - 3 * toolStripButtonZoomOut.Width - toolStripTextBox.Bounds.Left - 4;
        }

        private void toolStripTextBox_KeyPress(object sender, KeyPressEventArgs e)
        {
            if (e.KeyChar == 0xd)
            {
                if (!toolStripTextBox.Text.Contains("://"))
                    toolStripTextBox.Text = "https://" + toolStripTextBox.Text;
                webView.Uri = toolStripTextBox.Text;
            }
        }

        private void toolStripButtonCapture_Click(object sender, EventArgs e)
        {
            toolStripButtonCapture.Enabled = false;
            const string fileName = "preview.png";
            FileStream stream = new FileStream(fileName, FileMode.Create);
            webView.CapturePreview(CapturePreviewFormat.Png, stream, () =>
            {
                stream.Close();
                toolStripButtonCapture.Enabled = true;
                Process.Start(fileName);
            });
        }
    }
}